@@ -8,10 +8,7 @@ class Granule:
 
     def __init__(self, file_path, sidecar_path=None):
         self.file_path = file_path
-        if sidecar_path:
-            self.sidecar_path = sidecar_path
-        else:
-            self.sidecar_path = self.guess_sidecar_path()
+        self.sidecar_path = sidecar_path
         self.data = {}
         self.lat = None
         self.lon = None
@@ -31,42 +28,73 @@ class Granule:
             if target in names:
                 return name
             else:
-                return None
-                #raise SidecarNotFoundError(self.file_path)
+                raise starepandas.io.granules.SidecarNotFoundError(self.file_path)
         else:
             if glob.glob(name):
                 return name
             else:
-                return None
-                #raise SidecarNotFoundError(self.file_path)
+                raise starepandas.io.granules.SidecarNotFoundError(self.file_path)
 
     def guess_companion_path(self, prefix=None, folder=None):
         if prefix is None:
             prefix = self.companion_prefix
         return starepandas.io.granules.guess_companion_path(self.file_path, prefix=prefix, folder=folder)
 
-    def add_stare(self, adapt_resolution=True):
+    def add_sids(self, adapt_resolution=True):
         self.stare = pystare.from_latlon_2d(lat=self.lat, lon=self.lon, adapt_level=adapt_resolution)
 
     def read_sidecar_index(self, sidecar_path=None):
-        if not sidecar_path:
-            sidecar_path = self.sidecar_path
-        ds = starepandas.io.s3.nc4_dataset_wrapper(sidecar_path)
+        if sidecar_path is not None:
+            scp = sidecar_path
+        elif self.sidecar_path is not None:
+            scp = self.sidecar_path
+        else:
+            scp = self.guess_sidecar_path()
+        ds = starepandas.io.s3.nc4_dataset_wrapper(scp)
         self.stare = ds['STARE_index_{}'.format(self.nom_res)][:, :].astype(numpy.int64)
 
     def read_sidecar_cover(self, sidecar_path=None):
-        if not sidecar_path:
-            sidecar_path = self.sidecar_path
-        ds = starepandas.io.s3.nc4_dataset_wrapper(sidecar_path)
+        if sidecar_path:
+            scp = sidecar_path
+        elif self.sidecar_path:
+            scp = self.sidecar_path
+        else:
+            scp = self.guess_sidecar_path()
+        ds = starepandas.io.s3.nc4_dataset_wrapper(scp)
         self.stare_cover = ds['STARE_cover_{}'.format(self.nom_res)][:].astype(numpy.int64)
 
-    def to_df(self):
+    def to_df(self, xy=False):
+        """ Converts the granule object to a dataframe
+
+        Parameters
+        -----------
+        xy: bool
+            If true, add columns for the original array coordinates
+
+        Returns
+        --------
+        df: STAREDataFrame
+            dataframe containing lat, lon, xy, and data; one row per observation
+
+        """
         df = {}
         if self.lat is not None:
             df['lat'] = self.lat.flatten()
             df['lon'] = self.lon.flatten()
         if self.stare is not None:
-            df['stare'] = self.stare.flatten()
+            df['sids'] = self.stare.flatten()
+        if xy:
+            if self.lat is not None:
+                indices = numpy.indices(self.lat.shape)
+            elif self.stare is not None:
+                indices = numpy.indices(self.stare.shape)
+            else:
+                ds = list(self.data.values())[0]
+                indices = numpy.indices(ds.shape)
+            df['x'] = indices[0].flatten()
+            df['y'] = indices[1].flatten()
         for key in self.data.keys():
             df[key] = self.data[key].flatten()
         return starepandas.STAREDataFrame(df)
+
+
